<?php

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2013-2017 - Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * Plugin 'Quick Shop Installer' for the 'quickshop_installer' extension.
 *
 * @author    Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tx_quickshopinstaller
 * @version 7.0.5
 * @since 3.0.0
 */
class tx_quickshopinstaller_pi1_consolidate
{

	public $prefixId = 'tx_quickshopinstaller_pi1_consolidate'; // Same as class name
	public $scriptRelPath = 'pi1/class.tx_quickshopinstaller_pi1_consolidate.php'; // Path to this script relative to the extension dir.
	public $extKey = 'quickshop_installer';	// The extension key.
	public $pObj = null;
	private $powermailVersionAppendix = null;

	/*	 * *********************************************
	 *
	 * Main
	 *
	 * ******************************************** */

	/**
	 * main( )
	 *
	 * @return	void
	 * @access public
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	public function main()
	{
		$this->pObj->arrReport[] = '
      <h2>
       ' . $this->pObj->pi_getLL( 'consolidate_header' ) . '
      </h2>';

		$this->pageQuickshop();
		$this->pageQuickshopCaddy();
	}

	/*	 * *********************************************
	 *
	 * pages
	 *
	 * ******************************************** */

	/**
	 * pageQuickshop( )
	 *
	 * @return	void
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshop()
	{
		$records = array();
		$pageTitle = $GLOBALS[ 'TSFE' ]->page[ 'title' ];

		// Update page properties
		$records = $this->pageQuickshopProperties( );
		$this->sqlUpdatePages( $records, $pageTitle );

		// Hide the installer plugin
		$records = $this->pageQuickshopPluginInstallHide();
		$this->sqlUpdatePlugin( $records, $pageTitle );

		// Hide the TypoScript template
		$this->pageQuickshopTyposcriptOtherHide();
		$this->sqlUpdateTyposcriptOtherHide();
	}

	/**
	 * pageQuickshopCaddy( )
	 *
	 * @return	void
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddy()
	{
		$records = array();
		$pageTitle = $this->pObj->pi_getLL( 'pageQuickshopCaddy_title' );

//    // Update the jss script
//    $records = $this->pageQuickshopCaddyContentJss();
//    $this->sqlUpdateContent( $records, $pageTitle );
//
		// Update the powermail plugin
		$records = $this->pageQuickshopCaddyPluginPowermail();
		$this->sqlUpdatePlugin( $records, $pageTitle );

		// Update the caddy plugin
		$records = $this->pageQuickshopCaddyPluginCaddy();
		$this->sqlUpdatePlugin( $records, $pageTitle );

		// Update the caddy plugin
		$records = $this->pageQuickshopCaddyPluginCaddyMini();
		$this->sqlUpdatePlugin( $records, $pageTitle );

		// Update the TypoScript
		$records = $this->pageQuickshopCaddyTyposcript();
		$this->sqlUpdateTyposcript( $records, $pageTitle );
	}

	/**
	 * pageQuickshopCaddyContentJss( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @version 6.0.0
	 * @since   3.0.4
	 */
	private function pageQuickshopCaddyContentJss()
	{
		$records = null;
		$uid = $this->pObj->arr_contentUids[ 'content_caddy_header' ];

		// values
		$llHeader = $this->pObj->pi_getLL( 'content_caddy_header' );
		// values

		$pmFieldsetUid = $this->pObj->powermail->getValue( 'record_pm_fSets_title_deliveryAddress' );
		switch( true )
		{
			case( $this->pObj->powermailVersionInt < 1000000 ):
				$prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
			case( $this->pObj->powermailVersionInt < 2000000 ):
				$pmFieldsetHtmlId = 'tx-powermail-pi1_fieldset_' . $pmFieldsetUid;
				break;
			case( $this->pObj->powermailVersionInt < 4000000 ):
				$pmFieldsetHtmlId = 'powermail_fieldset_' . $pmFieldsetUid;
				break;
			case( $this->pObj->powermailVersionInt >= 4000000 ):
			default:
				$prompt = 'ERROR: unexpected result<br />
          powermail version is 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
		}

		$jssScript = $this->pObj->pi_getLL( 'content_caddy_bodytext' );
		$jssScript = str_replace( '###POWERMAIL_FIELDSET_DELIVERYORDER_ADDRESS###', $pmFieldsetHtmlId, $jssScript );


		$records[ $uid ][ 'header' ] = $llHeader;
		$records[ $uid ][ 'bodytext' ] = $jssScript;
		$records[ $uid ][ 'hidden' ] = 1;

		return $records;
	}

	/**
	 * pageQuickshopCaddyPluginCaddy( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyPluginCaddy()
	{
		$records = null;
		$uid = $this->pObj->arr_pluginUids[ 'plugin_caddy_header' ];
		$pmX = $this->powermailVersionAppendix();

		// values
		$llHeader = $this->pObj->pi_getLL( 'plugin_caddy_header' );
		// values

		$records[ $uid ][ 'header' ] = $llHeader;
		$records[ $uid ][ 'pi_flexform' ] = null .
						'<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="note">
            <language index="lDEF">
                <field index="note">
                    <value index="vDEF">'
						. $this->pObj->pi_getLL( 'plugin_caddy_note_note_' . $pmX ) .
						'</value>
                </field>
            </language>
        </sheet>
        <sheet index="origin">
            <language index="lDEF">
                <field index="order">
                    <value index="vDEF">10</value>
                </field>
                <field index="invoice">
                    <value index="vDEF">1000</value>
                </field>
                <field index="deliveryorder">
                    <value index="vDEF">100</value>
                </field>
                <field index="min">
                    <value index="vDEF">1</value>
                </field>
                <field index="max">
                    <value index="vDEF">100</value>
                </field>
            </language>
        </sheet>
        <sheet index="email">
            <language index="lDEF">
                <field index="customerEmail">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_email' ) .
						'</value>
                </field>
                <field index="termsMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="revocationMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="invoiceMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="deliveryorderMode">
                    <value index="vDEF">all</value>
                </field>
                <field index="orderconfirmationMode">
                    <value index="vDEF">all</value>
                </field>
            </language>
        </sheet>
        <sheet index="invoice">
            <language index="lDEF">
                <field index="company">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_companyBilling' ) .
						'</value>
                </field>
                <field index="firstName">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_firstnameBilling' ) .
						'</value>
                </field>
                <field index="lastName">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_surnameBilling' ) .
						'</value>
                </field>
                <field index="address">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_streetBilling' ) .
						'</value>
                </field>
                <field index="zip">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_zipBilling' ) .
						'</value>
                </field>
                <field index="city">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_locationBilling' ) .
						'</value>
                </field>
                <field index="country">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_countryBilling' ) .
						'</value>
                </field>
            </language>
        </sheet>
        <sheet index="deliveryorder">
            <language index="lDEF">
                <field index="company">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_companyDelivery' ) .
						'</value>
                </field>
                <field index="firstName">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_firstnameDelivery' ) .
						'</value>
                </field>
                <field index="lastName">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_surnameDelivery' ) .
						'</value>
                </field>
                <field index="address">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_streetDelivery' ) .
						'</value>
                </field>
                <field index="zip">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_zipDelivery' ) .
						'</value>
                </field>
                <field index="city">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_locationDelivery' ) .
						'</value>
                </field>
                <field index="country">
                    <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_countryDelivery' ) .
						'</value>
                </field>
            </language>
        </sheet>
        <sheet index="debit">
            <language index="lDEF">
                <field index="owner">
                  <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_accountowner' ) .
						'</value>
								</field>
                <field index="bic">
                  <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_bic' ) .
						'</value>
                </field>
                <field index="iban">
                  <value index="vDEF">'
						. $this->zz_getPowermailUid( 'record_pm_field_title_iban' ) .
						'</value>
                </field>
            </language>
        </sheet>
        <sheet index="paths">
            <language index="lDEF">
                <field index="terms">
                    <value index="vDEF">typo3conf/ext/quick_shop/Resources/Private/Pdf/typo3-quick-shop_for_caddy.pdf</value>
                </field>
                <field index="revocation">
                    <value index="vDEF">typo3conf/ext/quick_shop/Resources/Private/Pdf/typo3-quick-shop_for_caddy.pdf</value>
                </field>
                <field index="invoice">
                    <value index="vDEF">typo3conf/ext/quick_shop/Resources/Private/Pdf/typo3-quick-shop_for_caddy.pdf</value>
                </field>
                <field index="deliveryorder">
                    <value index="vDEF">typo3conf/ext/quick_shop/Resources/Private/Pdf/typo3-quick-shop_for_caddy.pdf</value>
                </field>
                <field index="orderconfirmation">
                    <value index="vDEF">typo3conf/ext/quick_shop/Resources/Private/Pdf/typo3-quick-shop_for_caddy.pdf</value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>
';

		return $records;
	}

	/**
	 * pageQuickshopCaddyPluginCaddyMini( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyPluginCaddyMini()
	{
		$records = null;
		$uid = $this->pObj->arr_pluginUids[ 'plugin_caddymini_header' ];

		// values
		$llHeader = $this->pObj->pi_getLL( 'plugin_caddymini_header' );
		$pidOfCaddy = $this->pObj->arr_pageUids[ 'pageQuickshopCaddy_title' ];
		// values

		$records[ $uid ][ 'header' ] = $llHeader;
		$records[ $uid ][ 'pi_flexform' ] = null .
						'<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="sDEF">
            <language index="lDEF">
                <field index="sdefPidCaddy">
                    <value index="vDEF">' . $pidOfCaddy . '</value>
                </field>
                <field index="sdefCaddyMode">
                    <value index="vDEF">woItems</value>
                </field>
                <field index="sdefDrs">
                    <value index="vDEF">0</value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>
';

		return $records;
	}

	/**
	 * pageQuickshopCaddyPluginPowermail( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyPluginPowermail()
	{
		$records = null;

		switch( true )
		{
			case( $this->pObj->powermailVersionInt < 1000000 ):
				$prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
			case( $this->pObj->powermailVersionInt < 2000000 ):
				$records = $this->pageQuickshopCaddyPluginPowermail1x();
				break;
			case( $this->pObj->powermailVersionInt < 4000000 ):
				$records = $this->pageQuickshopCaddyPluginPowermail2x();
				break;
			case( $this->pObj->powermailVersionInt >= 4000000 ):
			default:
				$prompt = 'ERROR: unexpected result<br />
          powermail version is 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
		}

		return $records;
	}

	/**
	 * pageQuickshopCaddyPluginPowermail1x( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyPluginPowermail1x()
	{
		$records = null;
		$uid = $this->pObj->arr_pluginUids[ 'plugin_powermail_header' ];

		// values
		$llHeader = $this->pObj->pi_getLL( 'plugin_powermail_header' );
		$uidEmail = $this->pObj->powermail->getValue( 'record_pm_field_title_email' );
		$customerEmail = 'uid' . $uidEmail;
		$uidFirstname = $this->pObj->powermail->getValue( 'record_pm_field_title_firstnameBilling' );
		$uidSurname = $this->pObj->powermail->getValue( 'record_pm_field_title_surnameBilling' );
		$customerName = 'uid' . $uidFirstname . ',uid' . $uidSurname;
		// values

		$records[ $uid ][ 'header' ] = $llHeader;
		$records[ $uid ][ 'tx_powermail_sender' ] = $customerEmail;
		$records[ $uid ][ 'tx_powermail_sendername' ] = $customerName;

		return $records;
	}

	/**
	 * pageQuickshopCaddyPluginPowermail2x( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @internal #i0047: settings.flexform.main.moresteps = 1
	 * @version 7.0.5
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyPluginPowermail2x()
	{
		$records = null;
		$uid = $this->pObj->arr_pluginUids[ 'plugin_powermail_header' ];

		$llHeader = $this->pObj->pi_getLL( 'plugin_powermail_header' );
		$uidForm = $this->pObj->powermail->getValue( 'record_pm_form_title_caddyorder' );
		$receiverSubject = $this->pObj->pi_getLL( 'plugin_powermail_subject_r2x' );
		$receiverBody = htmlspecialchars( $this->pObj->pi_getLL( 'plugin_powermail_body_r2x' ) );
		// #i0017, 140517, dwildt, 3-
		//list( $name, $domain) = explode( '@', $this->pObj->markerArray['###MAIL_DEFAULT_RECIPIENT###'] );
		//unset( $name );
		//$senderEmail      = 'noreply@' . $domain;
		// #i0017, 140517, dwildt, 1+
		$senderEmail = $this->pObj->markerArray[ '###MAIL_DEFAULT_RECIPIENT###' ];
		$senderSubject = $this->pObj->pi_getLL( 'plugin_powermail_subject_s2x' );
		$senderBody = htmlspecialchars( $this->pObj->pi_getLL( 'plugin_powermail_body_s2x' ) );
		$thxBody = htmlspecialchars( $this->pObj->pi_getLL( 'plugin_powermail_thanks2x' ) );

		$records[ $uid ][ 'header' ] = $llHeader;
		$records[ $uid ][ 'pi_flexform' ] = null .
						'<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="main">
            <language index="lDEF">
                <field index="settings.flexform.main.form">
                    <value index="vDEF">' . $uidForm . '</value>
                </field>
                <field index="settings.flexform.main.confirmation">
                    <value index="vDEF">1</value>
                </field>
                <field index="settings.flexform.main.moresteps">
                    <value index="vDEF">1</value>
                </field>
            </language>
        </sheet>
        <sheet index="receiver">
            <language index="lDEF">
                <field index="settings.flexform.receiver.name">
                    <value index="vDEF">{billingaddressfirstname} {billingaddresslastname}</value>
                </field>
                <field index="settings.flexform.receiver.email">
                    <value index="vDEF">' . $senderEmail . '</value>
                </field>
                <field index="settings.flexform.receiver.subject">
                    <value index="vDEF">' . $receiverSubject . '</value>
                </field>
                <field index="settings.flexform.receiver.body">
                    <value index="vDEF">' . $receiverBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $receiverBody . '</value>
                </field>
            </language>
        </sheet>
        <sheet index="sender">
            <language index="lDEF">
                <field index="settings.flexform.sender.name">
                    <value index="vDEF">Quick Shop</value>
                </field>
                <field index="settings.flexform.sender.email">
                    <value index="vDEF">' . $senderEmail . '</value>
                </field>
                <field index="settings.flexform.sender.subject">
                    <value index="vDEF">' . $senderSubject . '</value>
                </field>
                <field index="settings.flexform.sender.body">
                    <value index="vDEF">' . $senderBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $senderBody . '</value>
                </field>
            </language>
        </sheet>
        <sheet index="thx">
            <language index="lDEF">
                <field index="settings.flexform.thx.body">
                    <value index="vDEF">' . $thxBody . '</value>
                    <value index="_TRANSFORM_vDEF.vDEFbase">' . $thxBody . '</value>
                </field>
                <field index="settings.flexform.thx.redirect">
                    <value index="vDEF"></value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>';

		return $records;
	}

	/**
	 * pageQuickshopCaddyTyposcript( )
	 *
	 * @return	array		$records    : the TypoScript record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyTyposcript()
	{
		$records = null;

		$pmX = $this->powermailVersionAppendix();
		switch( true )
		{
			case( $pmX == '1x' ):
				$records = $this->pageQuickshopCaddyTyposcript1x();
				break;
			case( $pmX == '2x' ):
				$records = $this->pageQuickshopCaddyTyposcript2x();
				break;
			default:
				$prompt = 'ERROR: unexpected result<br />
          powermail version is neither 1x nor 2x. Internal: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
		}

		return $records;
	}

	/**
	 * pageQuickshopCaddyTyposcript1x( )
	 *
	 * @return	array		$records    : the TypoScript record
	 * @access private
	 * @version 6.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyTyposcript1x()
	{
		$records = null;

		$title = 'pageQuickshopCaddy_title';
		$uid = $this->pObj->arr_tsUids[ $title ];

		$strUid = sprintf( '%03d', $uid );
		$llTitle = strtolower( $this->pObj->pi_getLL( $title ) );
		$llTitle = str_replace( ' ', null, $llTitle );
		$llTitle = '+page_' . $llTitle . '_' . $strUid;

		list( $noreply, $domain ) = explode( '@', $this->pObj->markerArray[ '###MAIL_DEFAULT_RECIPIENT###' ] );
		$noreply = 'noreply@' . $domain;


		$records[ $uid ][ 'title' ] = $llTitle;
		$records[ $uid ][ 'constants' ] = '
  /////////////////////////////////////////
  //
  // INDEX
  //
  // plugin.caddy
  // plugin.powermail



//  Not needed: Is included at the root page
//
//  /////////////////////////////////////////
//  //
//  // plugin.caddy
//
//plugin.caddy {
//  pages {
//    caddy       = ' . $this->pObj->arr_pageUids[ 'pageQuickshopCaddy_title' ] . '
//    caddymini   = ' . $this->pObj->arr_pageUids[ 'pageQuickshopCaddyCaddymini_title' ] . '
//    revocation  = ' . $this->pObj->arr_pageUids[ 'pageQuickshopRevocation_title' ] . '
//    shop        = ' . $this->pObj->arr_pageUids[ 'pageOrg_title' ] . '
//    terms       = ' . $this->pObj->arr_pageUids[ 'pageQuickshopTerms_title' ] . '
//  }
//}
//  // plugin.caddy



  /////////////////////////////////////////
  //
  // plugin.powermail

plugin.powermail {
  js {
    toHeader = 1
  }
}
  // plugin.powermail

';

		$records[ $uid ][ 'config' ] = '
plugin.tx_powermail_pi1 {
  email {
    sender_mail {
      sender {
        name {
          value = Quick Shop
        }
        email {
          value = ' . $noreply . '
        }
      }
    }
  }
  _LOCAL_LANG {
    default {
      locallangmarker_confirmation_submit = Test Quick Shop without commitment!
    }
    de {
      locallangmarker_confirmation_submit = Quick Shop unverbindlich testen!
    }
  }
}';

		$installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
		switch( $installCase )
		{
			case( 'install_all' ):
				$records[ $uid ][ 'config' ] = $records[ $uid ][ 'config' ] . '

  // Don\'t display the mini caddy
page.10.subparts.menue.10 >
';
				break;
			case( 'install_shop' ):
				// Do nothing
				break;
			case( 'install_start' ):
				// Do nothing
				break;
			default:
				$prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
				die( $prompt );
		}

		return $records;
	}

	/**
	 * pageQuickshopCaddyTyposcript2x( )
	 *
	 * @return	array		$records    : the TypoScript record
	 * @access private
	 * @version 6.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopCaddyTyposcript2x()
	{
		$records = null;

		$title = 'pageQuickshopCaddy_title';
		$uid = $this->pObj->arr_tsUids[ $title ];

		$strUid = sprintf( '%03d', $uid );
		$llTitle = strtolower( $this->pObj->pi_getLL( $title ) );
		$llTitle = str_replace( ' ', null, $llTitle );
		$llTitle = '+page_' . $llTitle . '_' . $strUid;

		$records[ $uid ][ 'title' ] = $llTitle;
		$records[ $uid ][ 'constants' ] = '
  /////////////////////////////////////////
  //
  // INDEX
  //
  // plugin.caddy
  // plugin.powermail



//  Not needed: Is included at the root page
//
//  /////////////////////////////////////////
//  //
//  // plugin.caddy
//
//plugin.caddy {
//  pages {
//    caddy       = ' . $this->pObj->arr_pageUids[ 'pageQuickshopCaddy_title' ] . '
//    caddymini   = ' . $this->pObj->arr_pageUids[ 'pageQuickshopCaddyCaddymini_title' ] . '
//    revocation  = ' . $this->pObj->arr_pageUids[ 'pageQuickshopRevocation_title' ] . '
//    shop        = ' . $this->pObj->arr_pageUids[ 'pageOrg_title' ] . '
//    terms       = ' . $this->pObj->arr_pageUids[ 'pageQuickshopTerms_title' ] . '
//  }
//}
//  // plugin.caddy


  /////////////////////////////////////////
  //
  // plugin.caddy

plugin.caddy {
  deliveryaddress {
    includescript = 1
    powermail {
      debug = 0
    }
  }
  powermail {
    tabs {
      debug = 0
      id {
        tab01 = tab_' . $this->pObj->powermail->arr_recordUids[ 'record_pm_fSets_title_billingAddress' ] . '
        tab02 = tab_' . $this->pObj->powermail->arr_recordUids[ 'record_pm_fSets_title_deliveryAddress' ] . '
        tab03 = tab_' . $this->pObj->powermail->arr_recordUids[ 'record_pm_fSets_title_contactData' ] . '
        tab04 = tab_' . $this->pObj->powermail->arr_recordUids[ 'record_pm_fSets_title_order' ] . '
      }
      includescript = 1
    }
  }
}
  // plugin.caddy


  /////////////////////////////////////////
  //
  // plugin.tx_powermail

plugin.tx_powermail {
  settings {
    javascript {
        // We take jQuery from tx_browser_pi1 or from T3jQuery (recommended)
      powermailJQuery =
      powermailJQueryUi =
    }
  }
}
  // plugin.tx_powermail

';

		$records[ $uid ][ 'config' ] = '
plugin.tx_powermail {
  _LOCAL_LANG {
    default {
      confirmation_next = Order without commitment
    }
    de {
      confirmation_next = Unverbindlich testen
    }
  }
}
';

		$installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
		switch( $installCase )
		{
			case( 'install_all' ):
				$records[ $uid ][ 'config' ] = $records[ $uid ][ 'config' ] . '

  // Don\'t display the mini caddy
page.10.subparts.menue.10 >
';
				break;
			case( 'install_shop' ):
				// Do nothing
				break;
			case( 'install_start' ):
				// Do nothing
				break;
			default:
				$prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
				die( $prompt );
		}

		return $records;
	}

	/**
	 * pageQuickshopPluginInstallHide( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopPluginInstallHide()
	{
		$records = null;

		$uid = $this->pObj->cObj->data[ 'uid' ];
		$header = $this->pObj->cObj->data[ 'header' ];

		$records[ $uid ][ 'header' ] = $header;
		$records[ $uid ][ 'hidden' ] = 1;

		return $records;
	}

	/**
	 * pageQuickshopProperties( )
	 *
	 * @return	array		$records    : the TypoScript record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopProperties( )
	{
		$records = null;

		$uid = $GLOBALS[ 'TSFE' ]->id;
		$groupUid = $this->pObj->markerArray[ '###GROUP_UID###' ];
		$groupTitle = $this->pObj->markerArray[ '###GROUP_TITLE###' ];

		$installCase = $this->pObj->markerArray[ '###INSTALL_CASE###' ];
		switch( $installCase )
		{
			case( 'install_all' ):
				$records[ $uid ][ 'is_siteroot' ] = 1;
				$records[ $uid ][ 'nav_title' ] = null;
				break;
			case( 'install_shop' ):
				$records[ $uid ][ 'is_siteroot' ] = 0;
				$records[ $uid ][ 'nav_title' ] = $this->pObj->pi_getLL( 'pageQuickshop_titleNav' );
				break;
			case( 'install_start' ):
				$records[ $uid ][ 'backend_layout' ] = 'start__bronze_01';
				$records[ $uid ][ 'backend_layout_next_level' ] = 'start__bronze_01';
				$records[ $uid ][ 'is_siteroot' ] = 1;
				$records[ $uid ][ 'nav_title' ] = $this->pObj->pi_getLL( 'pageQuickshop_titleNav' );
				break;
			default:
				$prompt = __METHOD__ . ' #' . __LINE__ . ': Undefined value in switch: "' . $installCase . '"';
				die( $prompt );
		}

		// SWITCH : install case

		$records[ $uid ][ 'title' ] = $this->pObj->pi_getLL( 'pageQuickshop_title' );
		$records[ $uid ][ 'doktype' ] = 1; // 1: page
		$records[ $uid ][ 'nav_hide' ] = 0;
		$records[ $uid ][ 'media' ] = 'typo3_quickshop_' . $this->pObj->time . '.jpg';
		$records[ $uid ][ 'module' ] = null;
		$records[ $uid ][ 'TSconfig' ] = '

// QUICK SHOP INSTALLER at ' . date( 'Y-m-d G:i:s' ) . ' -- BEGIN

TCEMAIN {
  permissions {
    // ' . $groupUid . ': ' . $groupTitle . '
    groupid = ' . $groupUid . '
    group   = show,edit,delete,new,editcontent
  }
}

// QUICK SHOP INSTALLER at ' . date( 'Y-m-d G:i:s' ) . ' -- END

';

		return $records;
	}

	/**
	 * pageQuickshopTyposcriptOtherHide( )
	 *
	 * @return	array		$record : the TypoScript record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function pageQuickshopTyposcriptOtherHide()
	{
		// Do nothing
	}

	/*	 * *********************************************
	 *
	 * Sql
	 *
	 * ******************************************** */

	/**
	 * sqlUpdateContent( )
	 *
	 * @param	array		$records  : tt_content records for pages
	 * @param	string		$pageTitle  : title of the page
	 * @return	void
	 * @access private
	 * @version 3.0.4
	 * @since   3.0.4
	 */
	private function sqlUpdateContent( $records, $pageTitle )
	{
		$this->sqlUpdatePlugin( $records, $pageTitle );
	}

	/**
	 * sqlUpdatePlugin( )
	 *
	 * @param	array		$records  : tt_content records for pages
	 * @param	string		$pageTitle  : title of the page
	 * @return	void
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function sqlUpdatePlugin( $records, $pageTitle )
	{
		$table = 'tt_content';

		foreach( $records as $uid => $record )
		{
			$where = 'uid = ' . $uid;
			$fields = array_keys( $record );
			$csvFields = implode( ', ', $fields );
			$csvFields = str_replace( 'header, ', null, $csvFields );

			//var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
			$GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

			$error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

			if( $error )
			{
				$query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
				$prompt = 'SQL-ERROR<br />' . PHP_EOL .
								'query: ' . $query . '.<br />' . PHP_EOL .
								'error: ' . $error . '.<br />' . PHP_EOL .
								'Sorry for the trouble.<br />' . PHP_EOL .
								'TYPO3-Quick-Shop Installer<br />' . PHP_EOL .
								__METHOD__ . ' (' . __LINE__ . ')';
				die( $prompt );
			}

			$this->pObj->markerArray[ '###FIELD###' ] = $csvFields;
			$this->pObj->markerArray[ '###TITLE###' ] = '"' . $record[ 'header' ] . '"';
			$this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
			$prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_content' ) . '
        </p>';
			$prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
			$this->pObj->arrReport[] = $prompt;
		}
	}

	/**
	 * powermailVersionAppendix( )
	 *
	 * @return	array		$records : the plugin record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function powermailVersionAppendix()
	{
		if( $this->powermailVersionAppendix !== null )
		{
			return $this->powermailVersionAppendix;
		}

		switch( true )
		{
			case( $this->pObj->powermailVersionInt < 1000000 ):
				$prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
			case( $this->pObj->powermailVersionInt < 2000000 ):
				$this->powermailVersionAppendix = '1x';
				break;
			case( $this->pObj->powermailVersionInt < 4000000 ):
				$this->powermailVersionAppendix = '2x';
				break;
			case( $this->pObj->powermailVersionInt >= 4000000 ):
			default:
				$prompt = 'ERROR: unexpected result<br />
          powermail version is 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
		}

		return $this->powermailVersionAppendix;
	}

	/**
	 * sqlUpdatePages( )
	 *
	 * @param	array		$records  : TypoScript records for pages
	 * @param	string		$pageTitle  : title of the page
	 * @return	void
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function sqlUpdatePages( $records, $pageTitle )
	{
		$table = 'pages';

		foreach( $records as $uid => $record )
		{
			$where = 'uid = ' . $uid;
			$fields = array_keys( $record );
			$csvFields = implode( ', ', $fields );

//      var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
			$GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

			$error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

			if( $error )
			{
				$query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
				$prompt = 'SQL-ERROR<br />' . PHP_EOL .
								'query: ' . $query . '.<br />' . PHP_EOL .
								'error: ' . $error . '.<br />' . PHP_EOL .
								'Sorry for the trouble.<br />' . PHP_EOL .
								'TYPO3-Quick-Shop Installer<br />' . PHP_EOL .
								__METHOD__ . ' (' . __LINE__ . ')';
				die( $prompt );
			}

			$this->pObj->markerArray[ '###FIELD###' ] = $csvFields;
			$this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
			$prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_page' ) . '
        </p>';
			$prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
			$this->pObj->arrReport[] = $prompt;
		}
	}

	/**
	 * sqlUpdateTyposcript( )
	 *
	 * @param	array		$records  : TypoScript records for pages
	 * @param	string		$pageTitle  : title of the page
	 * @return	void
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function sqlUpdateTyposcript( $records, $pageTitle )
	{
		$table = 'sys_template';

		foreach( $records as $uid => $record )
		{
			$where = 'uid = ' . $uid;
			$fields = array_keys( $record );
			$csvFields = implode( ', ', $fields );
			$csvFields = str_replace( 'title, ', null, $csvFields );

			//var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
			$GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

			$error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

			if( $error )
			{
				$query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
				$prompt = 'SQL-ERROR<br />' . PHP_EOL .
								'query: ' . $query . '.<br />' . PHP_EOL .
								'error: ' . $error . '.<br />' . PHP_EOL .
								'Sorry for the trouble.<br />' . PHP_EOL .
								'TYPO3-Quick-Shop Installer<br />' . PHP_EOL .
								__METHOD__ . ' (' . __LINE__ . ')';
				die( $prompt );
			}
			$this->pObj->markerArray[ '###FIELD###' ] = $csvFields;
			$this->pObj->markerArray[ '###TITLE###' ] = '"' . $record[ 'title' ] . '"';
			$this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
			$prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_content' ) . '
        </p>';
			$prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
			$this->pObj->arrReport[] = $prompt;
		}
	}

	/**
	 * sqlUpdateTyposcriptOtherHide( )
	 *
	 * @return	void
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function sqlUpdateTyposcriptOtherHide()
	{
		$pageTitle = $GLOBALS[ 'TSFE' ]->page[ 'title' ];

		$table = 'sys_template';

		$record = array( 'hidden' => 1 );

		$uid = $this->pObj->arr_tsUids[ $this->pObj->str_tsRoot ];
		$pid = $GLOBALS[ 'TSFE' ]->id;
		$where = 'pid = ' . $pid . ' AND uid NOT LIKE ' . $uid;

		//var_dump( __METHOD__, __LINE__, $GLOBALS['TYPO3_DB']->UPDATEquery( $table, $where, $record ) );
		$GLOBALS[ 'TYPO3_DB' ]->exec_UPDATEquery( $table, $where, $record );

		$error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

		if( $error )
		{
			$query = $GLOBALS[ 'TYPO3_DB' ]->UPDATEquery( $table, $where, $record );
			$prompt = 'SQL-ERROR<br />' . PHP_EOL .
							'query: ' . $query . '.<br />' . PHP_EOL .
							'error: ' . $error . '.<br />' . PHP_EOL .
							'Sorry for the trouble.<br />' . PHP_EOL .
							'TYPO3-Quick-Shop Installer<br />' . PHP_EOL .
							__METHOD__ . ' (' . __LINE__ . ')';
			die( $prompt );
		}

		$this->pObj->markerArray[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $uid . ')';
		$prompt = '
      <p>
        ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'consolidate_prompt_template' ) . '
      </p>';
		$prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $this->pObj->markerArray );
		$this->pObj->arrReport[] = $prompt;
	}

	/*	 * *********************************************
	 *
	 * ZZ
	 *
	 * ******************************************** */

	/**
	 * zz_getPowermailUid( )
	 *
	 * @param	string		$label        : label for the powermail field
	 * @return	string		$powermailUid : uid of the powermail field record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function zz_getPowermailUid( $label )
	{
		$powermailUid = null;

		switch( true )
		{
			case( $this->pObj->powermailVersionInt < 1000000 ):
				$prompt = 'ERROR: unexpected result<br />
          powermail version is below 1.0.0: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
			case( $this->pObj->powermailVersionInt < 2000000 ):
				$powermailUid = $this->zz_getPowermailUid1x( $label );
				break;
			case( $this->pObj->powermailVersionInt < 4000000 ):
				$powermailUid = $this->zz_getPowermailUid2x( $label );
				break;
			case( $this->pObj->powermailVersionInt >= 4000000 ):
			default:
				$prompt = 'ERROR: unexpected result<br />
          powermail version is 3.x: ' . $this->pObj->powermailVersionInt . '<br />
          Method: ' . __METHOD__ . ' (line ' . __LINE__ . ')<br />
          TYPO3 extension: ' . $this->extKey;
				die( $prompt );
				break;
		}

		return $powermailUid;
	}

	/**
	 * zz_getPowermailUid1x( )
	 *
	 * @param	string		$label        : label for the powermail field
	 * @return	string		$powermailUid : uid of the powermail field record
	 * @access private
	 * @version 3.0.0
	 * @since   3.0.0
	 */
	private function zz_getPowermailUid1x( $label )
	{
		$powermailUid = $this->pObj->powermail->getValue( $label );

		return $powermailUid;
	}

	/**
	 * zz_getPowermailUid2x( )
	 *
	 * @param	string		$label        : label for the powermail field
	 * @return	string		$powermailUid : uid of the powermail field record
	 * @access private
	 * @version 7.0.0
	 * @since   3.0.0
	 */
	private function zz_getPowermailUid2x( $label )
	{
		// #t0963, 161121, dwildt, 1-/1+
		//$powermailUid = 'tx_powermail_domain_model_fields_' . $this->pObj->arr_recordUids[ $label ];
		$powermailUid = $this->pObj->powermail->getValue( $label );

		return $powermailUid;
	}

}

if( defined( 'TYPO3_MODE' ) && $TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/quickshop_installer/pi1/class.tx_quickshopinstaller_pi1_consolidate.php' ] )
{
	include_once($TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/quickshop_installer/pi1/class.tx_quickshopinstaller_pi1_consolidate.php' ]);
}