<?php

use TYPO3\CMS\Core\Utility\PathUtility;
use TYPO3\CMS\Core\Resource\ResourceFactory;

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2016-2017 - Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * Plugin 'Quick Shop Installer' for the 'quickshop_installer' extension.
 *
 * @author    Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package    TYPO3
 * @subpackage    tx_quickshopinstaller
 * @version 7.0.0
 * @since 7.0.0
 * @internal #t0963
 */
class tx_quickshopinstaller_pi1_fal
{

  public $prefixId = 'tx_quickshopinstaller_pi1_fal';                // Same as class name
  public $scriptRelPath = 'pi1/class.tx_quickshopinstaller_pi1_fal.php';  // Path to this script relative to the extension dir.
  public $extKey = 'org_installer';                      // The extension key.
  public $pObj = null;
	private $sysFileStorageUid = 0;
  private $uploadFolder = 'uploads/tx_quickshop/'; // Must correspond with tx_quickshopinstaller_pi1::zz_copyFiles

  /*   * *********************************************
   *
   * Main
   *
   * ******************************************** */

  /**
   * main( )
   *
   * @return	void
   * @access public
   * @version 7.0.0
   * @since   7.0.0
   */
  public function main()
  {
    $this->graphFuncObj = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance( \TYPO3\CMS\Core\Imaging\GraphicalFunctions::class );
    $this->graphFuncObj->init();

    $this->record();
  }

  /*   * *********************************************
   *
   * Records
   *
   * ******************************************** */

  /**
   * record( )
   *
   * @return	array		$records : the records
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function record()
  {
    $this->recordSysFileStorage();
    $this->recordSysFile();
		// #i0054, 170417, dwildt, 1-
//    $this->recordSysFileMetadata();
    $this->recordSysFileReference();
  }

  /**
   * recordSysFile( )
   *
   * @return	array		$records : the fieldset records
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function recordSysFile()
  {
    $this->recordSysFile_BasecapBlue( );
    $this->recordSysFile_BasecapGreen( );
    $this->recordSysFile_BasecapRed( );
    $this->recordSysFile_Book( );
    $this->recordSysFile_Cup( );
    $this->recordSysFile_Pullover( );
  }

  /**
   * recordSysFileMetadata( )
   *
   * @return	array		$records : the fieldset records
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileMetadata()
  {
    $table = 'sys_file_metadata';
    $records = array ();
    $uid = $this->pObj->zz_getMaxDbUid( $table );

    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileMetadata_BasecapBlue( $uid );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileMetadata_BasecapGreen( $uid );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileMetadata_BasecapRed( $uid );

    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileMetadata_Book( $uid );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileMetadata_Cup( $uid );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileMetadata_Pullover( $uid );

    $this->sqlInsert( $records, $table, __METHOD__, __LINE__ );
  }

  /**
   * recordSysFileReference( )
   *
   * @return	array		$records : the fieldset records
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileReference()
  {
    $table = 'sys_file_reference';
    $records = array ();
    $uid = $this->pObj->zz_getMaxDbUid( $table );

    $tablefield = 'tx_quickshop_products.image';
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileReference_BasecapBlue( $uid, $tablefield );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileReference_BasecapGreen( $uid, $tablefield );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileReference_BasecapRed( $uid, $tablefield );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileReference_Book( $uid, $tablefield );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileReference_Cup( $uid, $tablefield );
    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileReference_Pullover( $uid, $tablefield );

    $this->sqlInsert( $records, $table, __METHOD__, __LINE__ );
  }

  /**
   * recordSysFileStorage( )
   *
   * @return	array		$records : the fieldset records
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileStorage()
  {
    $table = 'sys_file_storage';
    $records = array ();
    $uid = $this->pObj->zz_getMaxDbUid( $table );

    $uid = $uid
      + 1;
    $records[ $uid ] = $this->recordSysFileStorage_Quickshop( $uid );

    $this->sqlInsert( $records, $table, __METHOD__, __LINE__ );
  }
  /**
   * recordSysFileMetadata_BasecapBlue( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileMetadata_BasecapBlue( $uid )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_capBlue';
    $llTitle = $this->pObj->pi_getLL( $llLabel );
    $this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

    $uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

    $llLabel = 'record_qs_prod_image_capBlue';
    $llImage = $this->pObj->pi_getLL( $llLabel );
    $info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage, $info );
//    die();

    $record[ 'uid' ] = $uid;
    $record[ 'alternative' ] = $llTitle;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'description' ] = $llTitle;
    $record[ 'file' ] = $uidSysFile;
    $record[ 'height' ] = $info[ 1 ];
    $record[ 'title' ] = $llTitle;
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'width' ] = $info[ 0 ];

    return $record;
  }

  /**
   * recordSysFileMetadata_BasecapGreen( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileMetadata_BasecapGreen( $uid )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_capGreen';
    $llTitle = $this->pObj->pi_getLL( $llLabel );
    $this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

    $uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

    $llLabel = 'record_qs_prod_image_capGreen';
    $llImage = $this->pObj->pi_getLL( $llLabel );
    $info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage, $info );
//    die();

    $record[ 'uid' ] = $uid;
    $record[ 'alternative' ] = $llTitle;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'description' ] = $llTitle;
    $record[ 'file' ] = $uidSysFile;
    $record[ 'height' ] = $info[ 1 ];
    $record[ 'title' ] = $llTitle;
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'width' ] = $info[ 0 ];

    return $record;
  }

  /**
   * recordSysFileMetadata_BasecapRed( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileMetadata_BasecapRed( $uid )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_capRed';
    $llTitle = $this->pObj->pi_getLL( $llLabel );
    $this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

    $uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

    $llLabel = 'record_qs_prod_image_capRed';
    $llImage = $this->pObj->pi_getLL( $llLabel );
    $info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage, $info );
//    die();

    $record[ 'uid' ] = $uid;
    $record[ 'alternative' ] = $llTitle;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'description' ] = $llTitle;
    $record[ 'file' ] = $uidSysFile;
    $record[ 'height' ] = $info[ 1 ];
    $record[ 'title' ] = $llTitle;
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'width' ] = $info[ 0 ];

    return $record;
  }

  /**
   * recordSysFileMetadata_Book( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileMetadata_Book( $uid )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_book';
    $llTitle = $this->pObj->pi_getLL( $llLabel );
    $this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

    $uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

    $llLabel = 'record_qs_prod_image_book';
    $llImage = $this->pObj->pi_getLL( $llLabel );
    $info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage, $info );
//    die();

    $record[ 'uid' ] = $uid;
    $record[ 'alternative' ] = $llTitle;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'description' ] = $llTitle;
    $record[ 'file' ] = $uidSysFile;
    $record[ 'height' ] = $info[ 1 ];
    $record[ 'title' ] = $llTitle;
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'width' ] = $info[ 0 ];

    return $record;
  }

  /**
   * recordSysFileMetadata_Cup( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileMetadata_Cup( $uid )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_cup';
    $llTitle = $this->pObj->pi_getLL( $llLabel );
    $this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

    $uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

    $llLabel = 'record_qs_prod_image_cup';
    $llImage = $this->pObj->pi_getLL( $llLabel );
    $info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage, $info );
//    die();

    $record[ 'uid' ] = $uid;
    $record[ 'alternative' ] = $llTitle;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'description' ] = $llTitle;
    $record[ 'file' ] = $uidSysFile;
    $record[ 'height' ] = $info[ 1 ];
    $record[ 'title' ] = $llTitle;
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'width' ] = $info[ 0 ];

    return $record;
  }

  /**
   * recordSysFileMetadata_Pullover( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileMetadata_Pullover( $uid )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_pullover';
    $llTitle = $this->pObj->pi_getLL( $llLabel );
    $this->pObj->arr_sysFileMetadataUids[ $llLabel ] = $uid;

    $uidSysFile = $this->pObj->arr_sysFileUids[ $llLabel ];

    $llLabel = 'record_qs_prod_image_pullover';
    $llImage = $this->pObj->pi_getLL( $llLabel );
    $info = $this->graphFuncObj->getImageDimensions( PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage );
//    var_dump(__METHOD__, __LINE__, PATH_typo3conf . 'ext/quickshop_installer/res/files/tx_quickshop_products/' . $llImage, $info );
//    die();

    $record[ 'uid' ] = $uid;
    $record[ 'alternative' ] = $llTitle;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'description' ] = $llTitle;
    $record[ 'file' ] = $uidSysFile;
    $record[ 'height' ] = $info[ 1 ];
    $record[ 'title' ] = $llTitle;
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'width' ] = $info[ 0 ];

    return $record;
  }

  /**
   * recordSysFileReference_BasecapBlue( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileReference_BasecapBlue( $uid, $tablefield )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_capBlue';
    $uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
    $this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
    $uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

    list($tablenames, $fieldname) = explode( '.', $tablefield );

    $record[ 'uid' ] = $uid;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'fieldname' ] = $fieldname;
    $record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageQuickshopItems_title' ];
    $record[ 'tablenames' ] = $tablenames;
    $record[ 'table_local' ] = 'sys_file';
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'uid_foreign' ] = $uid_foreign;
    $record[ 'uid_local' ] = $uid_local;

    return $record;
  }

  /**
   * recordSysFileReference_BasecapGreen( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileReference_BasecapGreen( $uid, $tablefield )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_capGreen';
    $uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
    $this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
    $uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

    list($tablenames, $fieldname) = explode( '.', $tablefield );

    $record[ 'uid' ] = $uid;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'fieldname' ] = $fieldname;
    $record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageQuickshopItems_title' ];
    $record[ 'tablenames' ] = $tablenames;
    $record[ 'table_local' ] = 'sys_file';
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'uid_foreign' ] = $uid_foreign;
    $record[ 'uid_local' ] = $uid_local;

    return $record;
  }

  /**
   * recordSysFileReference_BasecapRed( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileReference_BasecapRed( $uid, $tablefield )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_capRed';
    $uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
    $this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
    $uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

    list($tablenames, $fieldname) = explode( '.', $tablefield );

    $record[ 'uid' ] = $uid;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'fieldname' ] = $fieldname;
    $record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageQuickshopItems_title' ];
    $record[ 'tablenames' ] = $tablenames;
    $record[ 'table_local' ] = 'sys_file';
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'uid_foreign' ] = $uid_foreign;
    $record[ 'uid_local' ] = $uid_local;

    return $record;
  }

  /**
   * recordSysFileReference_Book( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileReference_Book( $uid, $tablefield )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_book';
    $uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
    $this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
    $uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

    list($tablenames, $fieldname) = explode( '.', $tablefield );

    $record[ 'uid' ] = $uid;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'fieldname' ] = $fieldname;
    $record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageQuickshopItems_title' ];
    $record[ 'tablenames' ] = $tablenames;
    $record[ 'table_local' ] = 'sys_file';
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'uid_foreign' ] = $uid_foreign;
    $record[ 'uid_local' ] = $uid_local;

    return $record;
  }

  /**
   * recordSysFileReference_Cup( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileReference_Cup( $uid, $tablefield )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_cup';
    $uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
    $this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
    $uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

    list($tablenames, $fieldname) = explode( '.', $tablefield );

    $record[ 'uid' ] = $uid;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'fieldname' ] = $fieldname;
    $record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageQuickshopItems_title' ];
    $record[ 'tablenames' ] = $tablenames;
    $record[ 'table_local' ] = 'sys_file';
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'uid_foreign' ] = $uid_foreign;
    $record[ 'uid_local' ] = $uid_local;

    return $record;
  }

  /**
   * recordSysFileReference_Pullover( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileReference_Pullover( $uid, $tablefield )
  {
    $record = array ();

    $llLabel = 'record_qs_prod_title_pullover';
    $uid_foreign = $this->pObj->arr_recordUids[ $llLabel ];
    $this->pObj->arr_sysFileReferenceUids[ $llLabel ] = $uid;
    $uid_local = $this->pObj->arr_sysFileUids[ $llLabel ];

    list($tablenames, $fieldname) = explode( '.', $tablefield );

    $record[ 'uid' ] = $uid;
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'fieldname' ] = $fieldname;
    $record[ 'pid' ] = $this->pObj->arr_pageUids[ 'pageQuickshopItems_title' ];
    $record[ 'tablenames' ] = $tablenames;
    $record[ 'table_local' ] = 'sys_file';
    $record[ 'tstamp' ] = $this->pObj->time;
    $record[ 'uid_foreign' ] = $uid_foreign;
    $record[ 'uid_local' ] = $uid_local;

    return $record;
  }

  /**
   * recordSysFileStorage_Quickshop( )
   *
   * @param	integer		$uid      : uid of the current fieldset
   * @return	array		$record   : the plugin record
   * @access private
   * @version 7.0.0
   * @since   7.0.0
   */
  private function recordSysFileStorage_Quickshop( $uid )
  {
    $record = array ();

    $record[ 'uid' ] = $uid;
//    $record[ 'auto_extract_metadata' ] = 1;  // Isn't compatible with TYPO3 6.x
    $record[ 'crdate' ] = $this->pObj->time;
    $record[ 'cruser_id' ] = $this->pObj->markerArray[ '###BE_USER###' ];
    $record[ 'configuration' ] = '<?xml version="1.0" encoding="utf-8" standalone="yes" ?>
<T3FlexForms>
    <data>
        <sheet index="sDEF">
            <language index="lDEF">
                <field index="basePath">
                    <value index="vDEF">uploads/tx_quickshop</value>
                </field>
                <field index="pathType">
                    <value index="vDEF">relative</value>
                </field>
                <field index="caseSensitive">
                    <value index="vDEF">1</value>
                </field>
            </language>
        </sheet>
    </data>
</T3FlexForms>';
    $record[ 'driver' ] = 'Local';
    $record[ 'is_browsable' ] = 1;
    $record[ 'is_online' ] = 1;
    $record[ 'is_public' ] = 1;
    $record[ 'is_writable' ] = 1;
    $record[ 'name' ] = 'Quick Shop';
    $record[ 'tstamp' ] = $this->pObj->time;

    return $record;
  }

  /**
   * recordSysFile_BasecapBlue( )
   *
   * @return	void
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function recordSysFile_BasecapBlue( )
  {
    $llTitle = 'record_qs_prod_title_capBlue';
    $llLabel = 'record_qs_prod_image_capBlue';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
  }

  /**
   * recordSysFile_BasecapGreen( )
   *
   * @return	void
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function recordSysFile_BasecapGreen( )
  {
    $llTitle = 'record_qs_prod_title_capGreen';
    $llLabel = 'record_qs_prod_image_capGreen';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
  }

  /**
   * recordSysFile_BasecapRed( )
   *
   * @return	void
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function recordSysFile_BasecapRed( )
  {
    $llTitle = 'record_qs_prod_title_capRed';
    $llLabel = 'record_qs_prod_image_capRed';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
  }

  /**
   * recordSysFile_Book( )
   *
   * @return	void
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function recordSysFile_Book( )
  {
    $llTitle = 'record_qs_prod_title_book';
    $llLabel = 'record_qs_prod_image_book';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
  }

  /**
   * recordSysFile_Cup( )
   *
   * @return	void
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function recordSysFile_Cup( )
  {
    $llTitle = 'record_qs_prod_title_cup';
    $llLabel = 'record_qs_prod_image_cup';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
  }

  /**
   * recordSysFile_Pullover( )
   *
   * @return	void
   * @access private
   * @version 7.0.9
   * @since   7.0.0
   */
  private function recordSysFile_Pullover( )
  {
    $llTitle = 'record_qs_prod_title_pullover';
    $llLabel = 'record_qs_prod_image_pullover';

		$llImage = $this->pObj->pi_getLL( $llLabel );
		$llImageWiTimestamp = str_replace( 'timestamp', $this->pObj->time, $llImage );
		$this->pObj->arr_fileUids[ $llImage ] = $llImageWiTimestamp;

		$this->pObj->arr_sysFileUids[ $llTitle ] = $this->zzSysFileInsert( $llImageWiTimestamp );
  }

  /*   * *********************************************
   *
   * Sql
   *
   * ******************************************** */

  /**
   * sqlInsert( )
   *
   * @param	array		$records : TypoScript records for pages
   * @param	[type]		$table: ...
   * @return	void
   * @access private
   * @version 6.0.0
   * @since   7.0.0
   */
  private function sqlInsert( $records, $table, $method = NULL, $line = NULL )
  {
    if ( empty( $method ) )
    {
      $method = __METHOD__;
    }
    if ( empty( $line ) )
    {
      $line = __LINE__;
    }
    foreach ( $records as $record )
    {
      //var_dump($GLOBALS['TYPO3_DB']->INSERTquery( $table, $record ) );
      $GLOBALS[ 'TYPO3_DB' ]->exec_INSERTquery( $table, $record );
      $error = $GLOBALS[ 'TYPO3_DB' ]->sql_error();

      if ( $error )
      {
        $query = $GLOBALS[ 'TYPO3_DB' ]->INSERTquery( $table, $record );
//        // #61666, 141003, dwildt
//        $prompt = 'SQL-ERROR<br />' . PHP_EOL .
//          'query: ' . $query . '.<br />' . PHP_EOL .
//          'error: ' . $error . '.<br />' . PHP_EOL .
//          'Sorry for the trouble.<br />' . PHP_EOL .
//          'TYPO3-Organiser Installer<br />' . PHP_EOL .
//          $method . ' (' . $line . ')';
        $prompt = '<div style="border:1em solid red;margin:1em;padding:2em;">' . PHP_EOL
          . 'SQL-ERROR<br />' . PHP_EOL
          . 'query: ' . $query . '.<br />' . PHP_EOL
          . 'error: ' . $error . '.<br />' . PHP_EOL
          . 'Sorry for the trouble.<br />' . PHP_EOL
          . 'TYPO3-Organiser Installer<br />' . PHP_EOL
          . $method . ' (' . $line . ')' . PHP_EOL
          . '</div>' . PHP_EOL
          . '<div style="border:1em solid blue;margin:1em;padding:2em;">' . PHP_EOL
          . 'HELP<br />' . PHP_EOL
          . '1. Please save the installer plugin again. Probably the SQL error is solved.<br />' . PHP_EOL
          . '2. Reload this page.<br />' . PHP_EOL
          . '3. If error occurs again, please update your database. <br />' . PHP_EOL
          . '   See: System > Install > Import action > Database analyzer [Compare current database with spezifications]<br />' . PHP_EOL
          . '4. Remove installed pages.<br />' . PHP_EOL
          . '5. Reload this page.' . PHP_EOL
          . '</div>' . PHP_EOL
          . '<pre>' . PHP_EOL
          . var_export( $records, TRUE )
          . '</pre>' . PHP_EOL
        ;
        die( $prompt );
      }

      // CONTINUE : pid is empty, no prompt
      if ( empty( $record[ 'pid' ] ) )
      {
        continue;
      }
      // CONTINUE : pid is empty, no prompt
      // prompt
      $pageTitle = $this->pObj->arr_pageTitles[ $record[ 'pid' ] ];
      $pageTitle = $this->pObj->pi_getLL( $pageTitle );

      $title = $record[ 'title' ];
      if ( empty( $title ) )
      {
        $title = $record[ 'header' ];
      }
      if ( empty( $title ) )
      {
        $title = $record[ 'name' ];
      }
      if ( empty( $title ) )
      {
        $title = '<i>no title</i>';
      }
      $marker[ '###TITLE###' ] = $title;
      $marker[ '###TABLE###' ] = $this->pObj->pi_getLL( $table, '<i>' . $table . '</i>' );
      $marker[ '###TITLE_PID###' ] = '"' . $pageTitle . '" (uid ' . $record[ 'pid' ] . ')';
      $prompt = '
        <p>
          ' . $this->pObj->arr_icons[ 'ok' ] . ' ' . $this->pObj->pi_getLL( 'record_create_prompt' ) . '
        </p>';
      $prompt = $this->pObj->cObj->substituteMarkerArray( $prompt, $marker );
      $this->pObj->arrReport[] = $prompt;
      // prompt
    }
  }

	/**
	 * zzSysFileInsert( )
	 *
	 * @param	string		$file
	 * @return	integer		Insert uid from sql database
	 * @access private
	 * @internal #i0054
	 * @version 7.0.9
	 * @since   7.0.9
	 */
	private function zzSysFileInsert( $file )
	{
		$pathAbs = PATH_site . $this->uploadFolder . $file;
		if( !file_exists( $pathAbs ) )
		{
			$prompt = 'FATAL ERROR! File does not exist: ' . $pathAbs;
			die( $prompt );
		}

		$identifier = PathUtility::getRelativePath( PATH_site, PATH_site . $this->uploadFolder ) . $file;
		$fileObject = ResourceFactory::getInstance()->getFileObjectByStorageAndIdentifier( $this->sysFileStorageUid, $identifier );
		$uid = $fileObject->getUid();
		return $uid;
	}

}

if ( defined( 'TYPO3_MODE' )
  && $TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/org_installer/pi1/class.tx_quickshopinstaller_pi1_org.php' ] )
{
  include_once($TYPO3_CONF_VARS[ TYPO3_MODE ][ 'XCLASS' ][ 'ext/org_installer/pi1/class.tx_quickshopinstaller_pi1_org.php' ]);
}